@@ -1,6 +1,6 @@
 #' Construction function for class "Emissions"
 #'
-#' @description Returns a tranformed object with class "Emissions".
+#' @description \code{Emissions} returns a tranformed object with class "Emissions".
 #' The type of objects supported are of classes "matrix", "data.frame" and
 #' "numeric". If the class of the object is "matrix" this function returns a
 #' dataframe.
@@ -10,7 +10,7 @@
 #' @param x Object with class "data.frame", "matrix" or "numeric"
 #' @param object object with class "Emissions"
 #' @param ... ignored
-#' @importFrom units parse_unit
+#' @importFrom units as_units
 #'
 #' @rdname Emissions
 #' @aliases Emissions print.Emissions summary.Emissions plot.Emissions
@@ -53,20 +53,20 @@ Emissions <- function(x, ...) {
   if ( is.matrix(x) ) {
     e <- as.data.frame(x)
     for(i in 1:ncol(e)){
-      e[,i] <- e[,i]*units::parse_unit("g h-1")
+      e[,i] <- e[,i]*units::as_units("g h-1")
     }
     class(e) <- c("Emissions", class(e))
   } else if ( is.data.frame(x) ) {
     e <- x
     for(i in 1:ncol(x)){
-      e[,i] <- e[,i]*units::parse_unit("g h-1")
+      e[,i] <- e[,i]*units::as_units("g h-1")
     }
     class(e) <- c("Emissions",class(x))
   } else if ( class(x) == "units" ) {
     e <- x
     warning("Check units are g/h")
   } else if( class(x) == "numeric" | class(x) == "integer") {
-    e <- x*units::parse_unit("g h-1")
+    e <- x*units::as_units("g h-1")
   }
   return(e)
 }
