@@ -1,6 +1,6 @@
 #' Construction function for class "Evaporative"
 #'
-#' @description Returns a tranformed object with class "Evaporative" and
+#' @description \code{Evaporative} returns a tranformed object with class "Evaporative" and
 #' units g/day. This class represents the daily emissions presented by
 #' Mellios G and Ntziachristos (2016) Gasoline evaporation, Tier 2. Eventually
 #' it will be incorporated the techniques of Tier 3.
@@ -27,7 +27,7 @@
 Evaporative <- function(x, ...) {
   ev <- x
 if ( is.numeric(ev) ) {
-    ev <- ev*units::parse_unit("g d-1")
+    ev <- ev*units::as_units("g d-1")
     class(ev) <- c("Evaporative",class(ev))
   }
   return(ev)
