@@ -1,8 +1,8 @@
 #' Estimation of VKM
 #'
-#' VKM consists in the product of the number of vehicles and the distance driven
-#' by these vehicles in km. This function reads hourly vehciles and then
-#' extrapolates the vehicles
+#' @description \code{vkm} consists in the product of the number of vehicles and
+#' the distance driven by these vehicles in km. This function reads hourly
+#' vehiles and then extrapolates the vehicles
 #'
 #' @param veh Numeric vector with number of vehicles per street
 #' @param lkm Length of each link (km)
@@ -17,14 +17,14 @@
 #' # Do not run
 #' pc <- lkm <- abs(rnorm(10,1,1))*100
 #' pro <- matrix(abs(rnorm(24*7,0.5,1)), ncol=7, nrow=24)
-#' vkms  <- vkm(veh = pc, lkm = lkm, profile = pro, hour = 24, day = 7, array = T)
+#' vkms  <- vkm(veh = pc, lkm = lkm, profile = pro)
 #' }
 vkm <- function (veh,
                  lkm,
                  profile,
-                 hour = 1,
-                 day = 1,
-                 array = F) {
+                 hour = 24,
+                 day = 7,
+                 array = T) {
   veh <- as.numeric(veh)
   lkm <- as.numeric(lkm)
   if(array == F){
